==> kubernetes-model-core-5.8.0-sources.jar: io/fabric8/kubernetes/api/model/ReplicationControllerStatusFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ReplicationControllerStatusFluent<A extends io.fabric8.kubernetes.api.model.ReplicationControllerStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.Integer getAvailableReplicas();
  public A withAvailableReplicas(java.lang.Integer availableReplicas);
  public java.lang.Boolean hasAvailableReplicas();
  public A addToConditions(java.lang.Integer index,io.fabric8.kubernetes.api.model.ReplicationControllerCondition item);
  public A setToConditions(java.lang.Integer index,io.fabric8.kubernetes.api.model.ReplicationControllerCondition item);
  public A addToConditions(io.fabric8.kubernetes.api.model.ReplicationControllerCondition... items);
  public A addAllToConditions(java.util.Collection<io.fabric8.kubernetes.api.model.ReplicationControllerCondition> items);
  public A removeFromConditions(io.fabric8.kubernetes.api.model.ReplicationControllerCondition... items);
  public A removeAllFromConditions(java.util.Collection<io.fabric8.kubernetes.api.model.ReplicationControllerCondition> items);
  public A removeMatchingFromConditions(java.util.function.Predicate<io.fabric8.kubernetes.api.model.ReplicationControllerConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.ReplicationControllerCondition> getConditions();
  public java.util.List<io.fabric8.kubernetes.api.model.ReplicationControllerCondition> buildConditions();
  public io.fabric8.kubernetes.api.model.ReplicationControllerCondition buildCondition(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.ReplicationControllerCondition buildFirstCondition();
  public io.fabric8.kubernetes.api.model.ReplicationControllerCondition buildLastCondition();
  public io.fabric8.kubernetes.api.model.ReplicationControllerCondition buildMatchingCondition(java.util.function.Predicate<io.fabric8.kubernetes.api.model.ReplicationControllerConditionBuilder> predicate);
  public java.lang.Boolean hasMatchingCondition(java.util.function.Predicate<io.fabric8.kubernetes.api.model.ReplicationControllerConditionBuilder> predicate);
  public A withConditions(java.util.List<io.fabric8.kubernetes.api.model.ReplicationControllerCondition> conditions);
  public A withConditions(io.fabric8.kubernetes.api.model.ReplicationControllerCondition... conditions);
  public java.lang.Boolean hasConditions();
  public A addNewCondition(java.lang.String lastTransitionTime,java.lang.String message,java.lang.String reason,java.lang.String status,java.lang.String type);
  public io.fabric8.kubernetes.api.model.ReplicationControllerStatusFluent.ConditionsNested<A> addNewCondition();
  public io.fabric8.kubernetes.api.model.ReplicationControllerStatusFluent.ConditionsNested<A> addNewConditionLike(io.fabric8.kubernetes.api.model.ReplicationControllerCondition item);
  public io.fabric8.kubernetes.api.model.ReplicationControllerStatusFluent.ConditionsNested<A> setNewConditionLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.ReplicationControllerCondition item);
  public io.fabric8.kubernetes.api.model.ReplicationControllerStatusFluent.ConditionsNested<A> editCondition(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.ReplicationControllerStatusFluent.ConditionsNested<A> editFirstCondition();
  public io.fabric8.kubernetes.api.model.ReplicationControllerStatusFluent.ConditionsNested<A> editLastCondition();
  public io.fabric8.kubernetes.api.model.ReplicationControllerStatusFluent.ConditionsNested<A> editMatchingCondition(java.util.function.Predicate<io.fabric8.kubernetes.api.model.ReplicationControllerConditionBuilder> predicate);
  public java.lang.Integer getFullyLabeledReplicas();
  public A withFullyLabeledReplicas(java.lang.Integer fullyLabeledReplicas);
  public java.lang.Boolean hasFullyLabeledReplicas();
  public java.lang.Long getObservedGeneration();
  public A withObservedGeneration(java.lang.Long observedGeneration);
  public java.lang.Boolean hasObservedGeneration();
  public java.lang.Integer getReadyReplicas();
  public A withReadyReplicas(java.lang.Integer readyReplicas);
  public java.lang.Boolean hasReadyReplicas();
  public java.lang.Integer getReplicas();
  public A withReplicas(java.lang.Integer replicas);
  public java.lang.Boolean hasReplicas();
  public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ReplicationControllerConditionFluent<io.fabric8.kubernetes.api.model.ReplicationControllerStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  
}

==> kubernetes-model-core-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/ReplicationControllerStatusFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface ReplicationControllerStatusFluent<A extends io.fabric8.kubernetes.api.model.ReplicationControllerStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.Integer getAvailableReplicas();
  public A withAvailableReplicas(java.lang.Integer availableReplicas);
  public java.lang.Boolean hasAvailableReplicas();
  public A addToConditions(java.lang.Integer index,io.fabric8.kubernetes.api.model.ReplicationControllerCondition item);
  public A setToConditions(java.lang.Integer index,io.fabric8.kubernetes.api.model.ReplicationControllerCondition item);
  public A addToConditions(io.fabric8.kubernetes.api.model.ReplicationControllerCondition... items);
  public A addAllToConditions(java.util.Collection<io.fabric8.kubernetes.api.model.ReplicationControllerCondition> items);
  public A removeFromConditions(io.fabric8.kubernetes.api.model.ReplicationControllerCondition... items);
  public A removeAllFromConditions(java.util.Collection<io.fabric8.kubernetes.api.model.ReplicationControllerCondition> items);
  public A removeMatchingFromConditions(java.util.function.Predicate<io.fabric8.kubernetes.api.model.ReplicationControllerConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.ReplicationControllerCondition> getConditions();
  public java.util.List<io.fabric8.kubernetes.api.model.ReplicationControllerCondition> buildConditions();
  public io.fabric8.kubernetes.api.model.ReplicationControllerCondition buildCondition(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.ReplicationControllerCondition buildFirstCondition();
  public io.fabric8.kubernetes.api.model.ReplicationControllerCondition buildLastCondition();
  public io.fabric8.kubernetes.api.model.ReplicationControllerCondition buildMatchingCondition(java.util.function.Predicate<io.fabric8.kubernetes.api.model.ReplicationControllerConditionBuilder> predicate);
  public java.lang.Boolean hasMatchingCondition(java.util.function.Predicate<io.fabric8.kubernetes.api.model.ReplicationControllerConditionBuilder> predicate);
  public A withConditions(java.util.List<io.fabric8.kubernetes.api.model.ReplicationControllerCondition> conditions);
  public A withConditions(io.fabric8.kubernetes.api.model.ReplicationControllerCondition... conditions);
  public java.lang.Boolean hasConditions();
  public A addNewCondition(java.lang.String lastTransitionTime,java.lang.String message,java.lang.String reason,java.lang.String status,java.lang.String type);
  public io.fabric8.kubernetes.api.model.ReplicationControllerStatusFluent.ConditionsNested<A> addNewCondition();
  public io.fabric8.kubernetes.api.model.ReplicationControllerStatusFluent.ConditionsNested<A> addNewConditionLike(io.fabric8.kubernetes.api.model.ReplicationControllerCondition item);
  public io.fabric8.kubernetes.api.model.ReplicationControllerStatusFluent.ConditionsNested<A> setNewConditionLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.ReplicationControllerCondition item);
  public io.fabric8.kubernetes.api.model.ReplicationControllerStatusFluent.ConditionsNested<A> editCondition(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.ReplicationControllerStatusFluent.ConditionsNested<A> editFirstCondition();
  public io.fabric8.kubernetes.api.model.ReplicationControllerStatusFluent.ConditionsNested<A> editLastCondition();
  public io.fabric8.kubernetes.api.model.ReplicationControllerStatusFluent.ConditionsNested<A> editMatchingCondition(java.util.function.Predicate<io.fabric8.kubernetes.api.model.ReplicationControllerConditionBuilder> predicate);
  public java.lang.Integer getFullyLabeledReplicas();
  public A withFullyLabeledReplicas(java.lang.Integer fullyLabeledReplicas);
  public java.lang.Boolean hasFullyLabeledReplicas();
  public java.lang.Long getObservedGeneration();
  public A withObservedGeneration(java.lang.Long observedGeneration);
  public java.lang.Boolean hasObservedGeneration();
  public java.lang.Integer getReadyReplicas();
  public A withReadyReplicas(java.lang.Integer readyReplicas);
  public java.lang.Boolean hasReadyReplicas();
  public java.lang.Integer getReplicas();
  public A withReplicas(java.lang.Integer replicas);
  public java.lang.Boolean hasReplicas();
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ReplicationControllerConditionFluent<io.fabric8.kubernetes.api.model.ReplicationControllerStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  
}
